==> tvb_library-1.5.9-py2-none-any.whl: tvb/simulator/models/__init__.py <==
# -*- coding: utf-8 -*-
#
#
#  TheVirtualBrain-Scientific Package. This package holds all simulators, and
# analysers necessary to run brain-simulations. You can use it stand alone or
# in conjunction with TheVirtualBrain-Framework Package. See content of the
# documentation-folder for more details. See also http://www.thevirtualbrain.org
#
# (c) 2012-2017, Baycrest Centre for Geriatric Care ("Baycrest") and others
#
# This program is free software: you can redistribute it and/or modify it under the
# terms of the GNU General Public License as published by the Free Software Foundation,
# either version 3 of the License, or (at your option) any later version.
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE.  See the GNU General Public License for more details.
# You should have received a copy of the GNU General Public License along with this
# program.  If not, see <http://www.gnu.org/licenses/>.
#
#
#   CITATION:
# When using The Virtual Brain for scientific publications, please cite it as follows:
#
#   Paula Sanz Leon, Stuart A. Knock, M. Marmaduke Woodman, Lia Domide,
#   Jochen Mersmann, Anthony R. McIntosh, Viktor Jirsa (2013)
#       The Virtual Brain: a simulator of primate brain network dynamics.
#   Frontiers in Neuroinformatics (7:10. doi: 10.3389/fninf.2013.00010)

"""
A collection of neuronal dynamics models.

Specific models inherit from the abstract class Model, which in turn inherits
from the class Trait from the tvb.basic.traits module.

.. moduleauthor:: Stuart A. Knock <Stuart@tvb.invalid>
.. moduleauthor:: Paula Sanz Leon <Paula@tvb.invalid>
.. moduleauthor:: Gaurav Malhotra <Gaurav@tvb.invalid>
.. moduleauthor:: Marmaduke Woodman <marmaduke.woodman@univ-amu.fr>

"""

from .base import Model
from .wilson_cowan import WilsonCowan
from .stefanescu_jirsa import ReducedSetFitzHughNagumo, ReducedSetHindmarshRose
from .jansen_rit import JansenRit, ZetterbergJansen
from .oscillator import Generic2dOscillator, Kuramoto
from .larter_breakspear import LarterBreakspear
from .wong_wang import ReducedWongWang
from .wong_wang_exc_io_inh_i import ReducedWongWangExcIOInhI
from .linear import Linear
from .hopfield import Hopfield
from .epileptor import Epileptor, Epileptor2D
from .JCepileptor import JC_Epileptor
from .epileptorcodim3 import EpileptorCodim3, EpileptorCodim3SlowMod
from .Zerlaut import Zerlaut_adaptation_first_order, Zerlaut_adaptation_second_order

==> tvb_library-2.0a0-py2-none-any.whl: tvb/simulator/models/__init__.py <==
# -*- coding: utf-8 -*-
#
#
#  TheVirtualBrain-Scientific Package. This package holds all simulators, and
# analysers necessary to run brain-simulations. You can use it stand alone or
# in conjunction with TheVirtualBrain-Framework Package. See content of the
# documentation-folder for more details. See also http://www.thevirtualbrain.org
#
# (c) 2012-2017, Baycrest Centre for Geriatric Care ("Baycrest") and others
#
# This program is free software: you can redistribute it and/or modify it under the
# terms of the GNU General Public License as published by the Free Software Foundation,
# either version 3 of the License, or (at your option) any later version.
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE.  See the GNU General Public License for more details.
# You should have received a copy of the GNU General Public License along with this
# program.  If not, see <http://www.gnu.org/licenses/>.
#
#
#   CITATION:
# When using The Virtual Brain for scientific publications, please cite it as follows:
#
#   Paula Sanz Leon, Stuart A. Knock, M. Marmaduke Woodman, Lia Domide,
#   Jochen Mersmann, Anthony R. McIntosh, Viktor Jirsa (2013)
#       The Virtual Brain: a simulator of primate brain network dynamics.
#   Frontiers in Neuroinformatics (7:10. doi: 10.3389/fninf.2013.00010)

"""
A collection of neuronal dynamics models.

Specific models inherit from the abstract class Model.

.. moduleauthor:: Stuart A. Knock <Stuart@tvb.invalid>
.. moduleauthor:: Paula Sanz Leon <Paula@tvb.invalid>
.. moduleauthor:: Gaurav Malhotra <Gaurav@tvb.invalid>
.. moduleauthor:: Marmaduke Woodman <marmaduke.woodman@univ-amu.fr>

"""

from .base import Model
from .epileptor import Epileptor, Epileptor2D
from .epileptor_rs import EpileptorRestingState
from .epileptorcodim3 import EpileptorCodim3, EpileptorCodim3SlowMod
from .hopfield import Hopfield
from .jansen_rit import JansenRit, ZetterbergJansen
from .larter_breakspear import LarterBreakspear
from .linear import Linear
from .oscillator import Generic2dOscillator, Kuramoto
from .stefanescu_jirsa import ReducedSetFitzHughNagumo, ReducedSetHindmarshRose
from .wilson_cowan import WilsonCowan
from .wong_wang import ReducedWongWang
from .wong_wang_exc_inh import ReducedWongWangExcInh
from .zerlaut import ZerlautFirstOrder, ZerlautSecondOrder
